@@ -51,16 +51,20 @@ module Debci
     def receive(directory)
       job = Debci::Job.receive(directory)
 
-      data = {
-        package: job.package.name,
-        suite: job.suite,
-        arch: job.arch,
-        backend: job.backend,
-        status: job.status,
-        duration_human: job.duration_human,
-        run_id: job.run_id,
-      }
-      Debci.log('%<package>s %<suite>s/%<arch>s/%<backend>s (%<run_id>s) %<status>s %<duration_human>s' % data)
+      if job.nil?
+        Debci.log("receiving from #{directory} failed associating a job")
+      else
+        data = {
+          package: job.package.name,
+          suite: job.suite,
+          arch: job.arch,
+          backend: job.backend,
+          status: job.status,
+          duration_human: job.duration_human,
+          run_id: job.run_id,
+        }
+        Debci.log('%<package>s %<suite>s/%<arch>s/%<backend>s (%<run_id>s) %<status>s %<duration_human>s' % data)
+      end
     end
 
     class CLI < Thor
