@@ -113,7 +113,12 @@ module Debci
       log_file = (@job.autopkgtest_dir / "log.gz").to_s
       @log = Debci::Log.new(log_file)
       @log.parse unless @too_large
-      erb :log_viewer
+      @base_url = "/data/autopkgtest/#{@job.suite}/#{@job.arch}/#{@job.package.prefix}/#{@job.package.name}/#{@job.run_id}"
+      if request.env["HTTP_ACCEPT"] == "text/plain"
+        redirect "#{@base_url}/log.gz"
+      else
+        erb :log_viewer
+      end
     end
 
     get "/:prefix/:package/:suite/:architecture/:run_id" do
