@@ -184,6 +184,9 @@ module Debci
       raise InvalidRequest.new('Please select an architecture') if archs.empty?
       invalid_extra_apt_sources = invalid_extra_apt_sources(extra_apt_sources)
       raise InvalidRequest.new("Please enter valid extra apt sources: Invalid apt sources: #{invalid_extra_apt_sources}") unless invalid_extra_apt_sources.empty?
+      raise InvalidRequest.new("Invalid suite: #{suite}") unless Debci.config.suite_list.include?(suite)
+      invalid_archs = archs.reject { |a| Debci.config.arch_list.include?(a) }
+      raise InvalidRequest.new("Invalid architectures: #{invalid_archs.join(', ')}") unless invalid_archs.empty?
     end
 
     post '/:user/test/upload' do
