@@ -5,5 +5,10 @@ module Debci
   class User < ActiveRecord::Base
     has_many :keys, class_name: 'Debci::Key'
     has_many :jobs, class_name: 'Debci::Job'
+
+    def to_str
+      # :nodoc:
+      username
+    end
   end
 end
