@@ -167,5 +167,13 @@ describe Debci::Frontend do
       expect(last_response.status).to eq(200)
       expect(last_response.body).to match(/Please download the raw log instead/i)
     end
+
+    it "redirects to actual log when Accept: text/plain" do
+      job = @rake.jobs.create!(requestor: theuser, suite: "unstable", arch: "arm64", log_size: 600.kilobytes)
+      header "Accept", "text/plain"
+      get "/packages/r/rake/unstable/arm64/#{job.run_id}/"
+      expect(last_response.status).to eq(302)
+      expect(last_response.headers["Location"]).to match(/log.gz$/)
+    end
   end
 end
