@@ -106,21 +106,26 @@ describe Debci::Job do
       expect(job.enqueue_parameters).to include(%r'signing-key:([A-Za-z0-9+/]{4})*([A-Za-z0-9+/]{3}=|[A-Za-z0-9+/]{2}==)?')
     end
 
-    it 'publishes message to the queue' do
-      queue = double("Queue")
-      expect(Debci::AMQP).to receive(:get_queue).and_return(queue)
-      expect(queue).to receive(:publish)
+    context 'actually sending to AMQP' do
+      before do
+        allow(Debci::AMQP).to receive(:queue_exists?).and_return(false)
+      end
+      it 'publishes message to the queue' do
+        queue = double("Queue")
+        expect(Debci::AMQP).to receive(:get_queue).and_return(queue)
+        expect(queue).to receive(:publish)
 
-      new_job.enqueue
-    end
-    it 'saves requested backend in the database' do
-      queue = double("Queue")
-      expect(Debci::AMQP).to receive(:get_queue).and_return(queue)
-      expect(queue).to receive(:publish)
+        new_job.enqueue
+      end
+      it 'saves requested backend in the database' do
+        queue = double("Queue")
+        expect(Debci::AMQP).to receive(:get_queue).and_return(queue)
+        expect(queue).to receive(:publish)
 
-      new_job.enqueue
-      new_job.reload
-      expect(new_job.requested_backend).to_not be_nil
+        new_job.enqueue
+        new_job.reload
+        expect(new_job.requested_backend).to_not be_nil
+      end
     end
   end
 
