@@ -130,4 +130,10 @@ describe Debci::Package do
       expect(Debci::Package.new(name: 'foo3', backend: 'abc')).to_not be_valid
     end
   end
+
+  it 'can have a storage limit' do
+    pkg = Debci::Package.new
+    expect(pkg.storage_limit).to be_nil
+    pkg.storage_limit = 1.gigabyte
+  end
 end
