@@ -150,6 +150,20 @@ describe Debci::SelfService do
       expect(Debci::Job.count).to eq(job_count)
       expect(last_response.status).to eq(400)
     end
+
+    it 'should return error when submitting form with incorrect suite' do
+      job_count = Debci::Job.count
+      post '/user/foo@bar.com/test/submit', pin_packages: '', package: 'test-package', suite: "invalid", arch: [arch]
+      expect(Debci::Job.count).to eq(job_count)
+      expect(last_response.status).to eq(400)
+    end
+
+    it 'should return error when submitting form with incorrect arch' do
+      job_count = Debci::Job.count
+      post '/user/foo@bar.com/test/submit', pin_packages: '', package: 'test-package', suite: suite, arch: ["invalid"]
+      expect(Debci::Job.count).to eq(job_count)
+      expect(last_response.status).to eq(400)
+    end
   end
 
   context 'managing keys' do
