@@ -26,6 +26,5 @@ exec rerun \
   --name $(basename $0 .sh) \
   --no-notify \
   --background \
-  --dir lib \
-  -p '**/*.rb' -- \
+  -p '{config.ru,lib/**/*.rb}' -- \
   puma --silent --quiet --include lib --bind=tcp://0.0.0.0:${port} --bind=ssl://0.0.0.0:$((port + 1)) config.ru
